@@ -391,6 +391,8 @@ typedef struct wan_xilinx_conf_if
 #if defined(__WINDOWS__)
 	unsigned char  tdmv_hwec;
 #endif
+	unsigned int	rx_error_threshold; /* Monitor for excessive rx errors, threshold per second */
+	unsigned int	rx_error_recovery;  /* Timeout to recover after excessive errros, seconds */
 }wan_xilinx_conf_if_t;
 
 
