@@ -838,7 +838,7 @@ static int new_if (wan_device_t* wandev, netdevice_t* dev, wanif_conf_t* conf)
 	 * can return an error */
 
 	dev->init = &if_init;
-	dev->priv = chdlc_priv_area;
+	wan_netif_set_priv(dev, chdlc_priv_area);
 
 	set_bit(0,&chdlc_priv_area->config_chdlc);
 
@@ -854,8 +854,7 @@ new_if_error:
 	wan_unreg_api(chdlc_priv_area, card->devname);
 	
 	kfree(chdlc_priv_area);
-
-	dev->priv=NULL;
+	wan_netif_set_priv(dev, NULL);
 
 	return err;
 }
@@ -876,7 +875,7 @@ new_if_error:
  */
 static int del_if (wan_device_t* wandev, netdevice_t* dev)
 {
-	chdlc_private_area_t* 	chdlc_priv_area = dev->priv;
+	chdlc_private_area_t* 	chdlc_priv_area = wan_netif_priv(dev);
 	sdla_t*			card = chdlc_priv_area->card;
 
 	WAN_TASKLET_KILL(&chdlc_priv_area->common.bh_task);
@@ -908,7 +907,7 @@ static int del_if (wan_device_t* wandev, netdevice_t* dev)
  */
 static int if_init (netdevice_t* dev)
 {
-	chdlc_private_area_t* chdlc_priv_area = dev->priv;
+	chdlc_private_area_t* chdlc_priv_area = wan_netif_priv(dev);
 	sdla_t* card = chdlc_priv_area->card;
 	wan_device_t* wandev = &card->wandev;
 
@@ -994,7 +993,7 @@ static int if_init (netdevice_t* dev)
  */
 static int if_open (netdevice_t* dev)
 {
-	chdlc_private_area_t* chdlc_priv_area = dev->priv;
+	chdlc_private_area_t* chdlc_priv_area = wan_netif_priv(dev);
 	sdla_t* card = chdlc_priv_area->card;
 	struct timeval tv;
 	int err = 0;
@@ -1053,7 +1052,7 @@ static int if_open (netdevice_t* dev)
 
 static int if_close (netdevice_t* dev)
 {
-	chdlc_private_area_t* chdlc_priv_area = dev->priv;
+	chdlc_private_area_t* chdlc_priv_area = wan_netif_priv(dev);
 	sdla_t* card = chdlc_priv_area->card;
 
 	stop_net_queue(dev);
@@ -1124,7 +1123,7 @@ static void disable_comm (sdla_t *card)
  */
 static void if_tx_timeout (netdevice_t *dev)
 {
-    	chdlc_private_area_t* chan = dev->priv;
+    	chdlc_private_area_t* chan = wan_netif_priv(dev);
 	sdla_t *card = chan->card;
 	
 	/* If our device stays busy for at least 5 seconds then we will
@@ -1167,7 +1166,7 @@ static void if_tx_timeout (netdevice_t *dev)
  */
 static int if_send (struct sk_buff* skb, netdevice_t* dev)
 {
-	chdlc_private_area_t *chdlc_priv_area = dev->priv;
+	chdlc_private_area_t *chdlc_priv_area = wan_netif_priv(dev);
 	sdla_t *card = chdlc_priv_area->card;
 	int udp_type = 0;
 	unsigned long smp_flags;
@@ -1318,7 +1317,7 @@ static int chk_bcast_mcast_addr(sdla_t *card, netdevice_t* dev,
 {
 	u32 src_ip_addr;
         u32 broadcast_ip_addr = 0;
-	chdlc_private_area_t *chdlc_priv_area=dev->priv;
+	chdlc_private_area_t *chdlc_priv_area=wan_netif_priv(dev);
         struct in_device *in_dev;
         /* read the IP source address from the outgoing packet */
         src_ip_addr = *(u32 *)(skb->data + 12);
@@ -1465,7 +1464,7 @@ static struct net_device_stats* if_stats (netdevice_t* dev)
 	sdla_t *my_card;
 	chdlc_private_area_t* chdlc_priv_area;
 
-	if ((chdlc_priv_area=dev->priv) == NULL)
+	if ((chdlc_priv_area=wan_netif_priv(dev)) == NULL)
 		return NULL;
 
 	my_card = chdlc_priv_area->card;
@@ -1862,7 +1861,7 @@ static void wpc_isr (sdla_t* card)
 		card->hw_iface.clear_bit(card->hw, card->intr_perm_off, APP_INT_ON_TX);
 
 		if (dev && is_queue_stopped(dev)){
-			chdlc_private_area_t* chdlc_priv_area=dev->priv;
+			chdlc_private_area_t* chdlc_priv_area=wan_netif_priv(dev);
 			
 			if (chdlc_priv_area->common.usedby == API){
 				start_net_queue(dev);
@@ -2140,7 +2139,7 @@ void timer_intr(sdla_t *card)
 		goto timer_isr_exit;
 	}
 	
-        chdlc_priv_area = dev->priv;
+        chdlc_priv_area = wan_netif_priv(dev);
 
 	/* Configure hardware */
 	if (card->u.c.timer_int_enabled & TMR_INT_ENABLED_CONFIG) {
@@ -2344,7 +2343,7 @@ static int process_global_exception(sdla_t *card)
 /* SNMP */ 
 static int if_do_ioctl(netdevice_t *dev, struct ifreq *ifr, int cmd)
 {
-	chdlc_private_area_t* chan= (chdlc_private_area_t*)dev->priv;
+	chdlc_private_area_t* chan= wan_netif_priv(dev);
 	unsigned long smp_flags;
 	sdla_t *card;
 	wan_udp_pkt_t *wan_udp_pkt;
@@ -3136,14 +3135,11 @@ static int chdlc_set_if_info(struct file *file,
 			     void *data)
 {
 	netdevice_t*		dev = (void*)data;
-	chdlc_private_area_t* 	chdlc_priv_area = NULL;
+	chdlc_private_area_t* 	chdlc_priv_area;
 
-	if (dev == NULL || dev->priv == NULL)
+	if (dev == NULL || (chdlc_priv_area = wan_netif_priv(dev)) == NULL)
 		return count;
 
-	chdlc_priv_area = (chdlc_private_area_t*)dev->priv;
-
-
 	printk(KERN_INFO "%s: New interface config (%s)\n",
 			chdlc_priv_area->if_name, buffer);
 	/* Parse string */
